@@ -51,7 +51,7 @@
 #include <pyside2_qtgui_python.h>
 #include <pyside2_qtcore_python.h>
 
-// Binded library includes
+// Bound library includes
 #include <Qt3DLogic/qframeaction.h>
 #include <Qt3DLogic/qlogicaspect.h>
 // Conversion Includes - Primitive Types
@@ -105,8 +105,11 @@ namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
 template<> inline PyTypeObject *SbkType< ::Qt3DLogic::QFrameAction >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DLogicTypes[SBK_QT3DLOGIC_QFRAMEACTION_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DLogic::QLogicAspect >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DLogicTypes[SBK_QT3DLOGIC_QLOGICASPECT_IDX]); }
+QT_WARNING_POP
 
 } // namespace Shiboken
 
