@@ -46,12 +46,6 @@
 
 #include <sbkpython.h>
 #include <sbkconverter.h>
-#include <sbkenum.h>
-#include <basewrapper.h>
-#include <bindingmanager.h>
-#include <memory>
-
-#include <pysidesignal.h>
 // Module Includes
 #include <pyside2_qtcore_python.h>
 #include <pyside2_qtgui_python.h>
@@ -59,63 +53,71 @@
 #include <pyside2_qtnetwork_python.h>
 #include <pyside2_qtwidgets_python.h>
 
-// Binded library includes
-#include <qcameraviewfinder.h>
-#include <qvideowidgetcontrol.h>
-#include <qvideowidget.h>
-#include <qgraphicsvideoitem.h>
+// Bound library includes
+#include <QtMultimediaWidgets/qcameraviewfinder.h>
+#include <QtMultimediaWidgets/qvideowidget.h>
+#include <QtMultimediaWidgets/qgraphicsvideoitem.h>
+#include <QtMultimediaWidgets/qvideowidgetcontrol.h>
 // Conversion Includes - Primitive Types
-#include <QStringList>
-#include <QString>
-#include <signalmanager.h>
 #include <qabstractitemmodel.h>
+#include <QString>
+#include <QStringList>
+#include <signalmanager.h>
 
 // Conversion Includes - Container Types
-#include <QSet>
-#include <QList>
-#include <QMultiMap>
-#include <QMap>
+#include <pysideqflags.h>
 #include <QLinkedList>
+#include <QList>
+#include <QMap>
+#include <QMultiMap>
+#include <QPair>
+#include <QQueue>
+#include <QSet>
 #include <QStack>
 #include <QVector>
-#include <QQueue>
-#include <QPair>
-#include <pysideqflags.h>
 
 // Type indices
-#define SBK_QVIDEOWIDGET_IDX                                         2
-#define SBK_QCAMERAVIEWFINDER_IDX                                    0
-#define SBK_QGRAPHICSVIDEOITEM_IDX                                   1
-#define SBK_QVIDEOWIDGETCONTROL_IDX                                  3
-#define SBK_QtMultimediaWidgets_IDX_COUNT                            4
-
+enum : int {
+    SBK_QCAMERAVIEWFINDER_IDX                                = 0,
+    SBK_QGRAPHICSVIDEOITEM_IDX                               = 1,
+    SBK_QVIDEOWIDGET_IDX                                     = 2,
+    SBK_QVIDEOWIDGETCONTROL_IDX                              = 3,
+    SBK_QtMultimediaWidgets_IDX_COUNT                        = 4
+};
 // This variable stores all Python types exported by this module.
-extern PyTypeObject** SbkPySide2_QtMultimediaWidgetsTypes;
+extern PyTypeObject **SbkPySide2_QtMultimediaWidgetsTypes;
+
+// This variable stores the Python module object exported by this module.
+extern PyObject *SbkPySide2_QtMultimediaWidgetsModuleObject;
 
 // This variable stores all type converters exported by this module.
-extern SbkConverter** SbkPySide2_QtMultimediaWidgetsTypeConverters;
+extern SbkConverter **SbkPySide2_QtMultimediaWidgetsTypeConverters;
 
 // Converter indices
-#define SBK_QTMULTIMEDIAWIDGETS_QLIST_QACTIONPTR_IDX                 0 // QList<QAction* >
-#define SBK_QTMULTIMEDIAWIDGETS_QLIST_QOBJECTPTR_IDX                 1 // const QList<QObject* > &
-#define SBK_QTMULTIMEDIAWIDGETS_QLIST_QBYTEARRAY_IDX                 2 // QList<QByteArray >
-#define SBK_QTMULTIMEDIAWIDGETS_QLIST_QGRAPHICSITEMPTR_IDX           3 // QList<QGraphicsItem* >
-#define SBK_QTMULTIMEDIAWIDGETS_QLIST_QGRAPHICSTRANSFORMPTR_IDX      4 // const QList<QGraphicsTransform* > &
-#define SBK_QTMULTIMEDIAWIDGETS_QLIST_QVARIANT_IDX                   5 // QList<QVariant >
-#define SBK_QTMULTIMEDIAWIDGETS_QLIST_QSTRING_IDX                    6 // QList<QString >
-#define SBK_QTMULTIMEDIAWIDGETS_QMAP_QSTRING_QVARIANT_IDX            7 // QMap<QString,QVariant >
-#define SBK_QtMultimediaWidgets_CONVERTERS_IDX_COUNT                 8
-
+enum : int {
+    SBK_QTMULTIMEDIAWIDGETS_QLIST_QGRAPHICSITEMPTR_IDX       = 0, // QList<QGraphicsItem* >
+    SBK_QTMULTIMEDIAWIDGETS_QLIST_QOBJECTPTR_IDX             = 1, // const QList<QObject* > &
+    SBK_QTMULTIMEDIAWIDGETS_QLIST_QBYTEARRAY_IDX             = 2, // QList<QByteArray >
+    SBK_QTMULTIMEDIAWIDGETS_QLIST_QGRAPHICSTRANSFORMPTR_IDX  = 3, // const QList<QGraphicsTransform* > &
+    SBK_QTMULTIMEDIAWIDGETS_QLIST_QACTIONPTR_IDX             = 4, // QList<QAction* >
+    SBK_QTMULTIMEDIAWIDGETS_QLIST_QVARIANT_IDX               = 5, // QList<QVariant >
+    SBK_QTMULTIMEDIAWIDGETS_QLIST_QSTRING_IDX                = 6, // QList<QString >
+    SBK_QTMULTIMEDIAWIDGETS_QMAP_QSTRING_QVARIANT_IDX        = 7, // QMap<QString,QVariant >
+    SBK_QtMultimediaWidgets_CONVERTERS_IDX_COUNT             = 8
+};
 // Macros for type check
 
 namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
-template<> inline PyTypeObject* SbkType< ::QVideoWidget >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtMultimediaWidgetsTypes[SBK_QVIDEOWIDGET_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QCameraViewfinder >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtMultimediaWidgetsTypes[SBK_QCAMERAVIEWFINDER_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QGraphicsVideoItem >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtMultimediaWidgetsTypes[SBK_QGRAPHICSVIDEOITEM_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QVideoWidgetControl >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtMultimediaWidgetsTypes[SBK_QVIDEOWIDGETCONTROL_IDX]); }
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
+template<> inline PyTypeObject *SbkType< ::QCameraViewfinder >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtMultimediaWidgetsTypes[SBK_QCAMERAVIEWFINDER_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QGraphicsVideoItem >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtMultimediaWidgetsTypes[SBK_QGRAPHICSVIDEOITEM_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QVideoWidget >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtMultimediaWidgetsTypes[SBK_QVIDEOWIDGET_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QVideoWidgetControl >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtMultimediaWidgetsTypes[SBK_QVIDEOWIDGETCONTROL_IDX]); }
+QT_WARNING_POP
 
 } // namespace Shiboken
 
