@@ -51,7 +51,7 @@
 #include <pyside2_qtgui_python.h>
 #include <pyside2_qtcore_python.h>
 
-// Binded library includes
+// Bound library includes
 #include <QtPrintSupport/qprintengine.h>
 #include <QtPrintSupport/qprintpreviewwidget.h>
 #include <QtPrintSupport/qprintdialog.h>
@@ -138,6 +138,8 @@ namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
 template<> inline PyTypeObject *SbkType< ::QAbstractPrintDialog::PrintRange >() { return SbkPySide2_QtPrintSupportTypes[SBK_QABSTRACTPRINTDIALOG_PRINTRANGE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QAbstractPrintDialog::PrintDialogOption >() { return SbkPySide2_QtPrintSupportTypes[SBK_QABSTRACTPRINTDIALOG_PRINTDIALOGOPTION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QFlags<QAbstractPrintDialog::PrintDialogOption> >() { return SbkPySide2_QtPrintSupportTypes[SBK_QFLAGS_QABSTRACTPRINTDIALOG_PRINTDIALOGOPTION_IDX]; }
@@ -162,6 +164,7 @@ template<> inline PyTypeObject *SbkType< ::QPrinter::Unit >() { return SbkPySide
 template<> inline PyTypeObject *SbkType< ::QPrinter::DuplexMode >() { return SbkPySide2_QtPrintSupportTypes[SBK_QPRINTER_DUPLEXMODE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QPrinter >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtPrintSupportTypes[SBK_QPRINTER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QPrinterInfo >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtPrintSupportTypes[SBK_QPRINTERINFO_IDX]); }
+QT_WARNING_POP
 
 } // namespace Shiboken
 
