@@ -51,7 +51,7 @@
 #include <pyside2_qtgui_python.h>
 #include <pyside2_qtwidgets_python.h>
 
-// Binded library includes
+// Bound library includes
 #include <QtTest/qtestmouse.h>
 #include <QtTest/qttestglobal.h>
 #include <QtTest/qbenchmarkmetric.h>
@@ -86,13 +86,13 @@ enum : int {
     SBK_QtTest_IDX_COUNT                                     = 6
 };
 // This variable stores all Python types exported by this module.
-extern PyTypeObject** SbkPySide2_QtTestTypes;
+extern PyTypeObject **SbkPySide2_QtTestTypes;
 
 // This variable stores the Python module object exported by this module.
-extern PyObject* SbkPySide2_QtTestModuleObject;
+extern PyObject *SbkPySide2_QtTestModuleObject;
 
 // This variable stores all type converters exported by this module.
-extern SbkConverter** SbkPySide2_QtTestTypeConverters;
+extern SbkConverter **SbkPySide2_QtTestTypeConverters;
 
 // Converter indices
 enum : int {
@@ -107,11 +107,14 @@ namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
-template<> inline PyTypeObject* SbkType< ::QTest::TestFailMode >() { return SbkPySide2_QtTestTypes[SBK_QTEST_TESTFAILMODE_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QTest::QBenchmarkMetric >() { return SbkPySide2_QtTestTypes[SBK_QTEST_QBENCHMARKMETRIC_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QTest::KeyAction >() { return SbkPySide2_QtTestTypes[SBK_QTEST_KEYACTION_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QTest::MouseAction >() { return SbkPySide2_QtTestTypes[SBK_QTEST_MOUSEACTION_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QTest::PySideQTouchEventSequence >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtTestTypes[SBK_QTEST_PYSIDEQTOUCHEVENTSEQUENCE_IDX]); }
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
+template<> inline PyTypeObject *SbkType< ::QTest::TestFailMode >() { return SbkPySide2_QtTestTypes[SBK_QTEST_TESTFAILMODE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QTest::QBenchmarkMetric >() { return SbkPySide2_QtTestTypes[SBK_QTEST_QBENCHMARKMETRIC_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QTest::KeyAction >() { return SbkPySide2_QtTestTypes[SBK_QTEST_KEYACTION_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QTest::MouseAction >() { return SbkPySide2_QtTestTypes[SBK_QTEST_MOUSEACTION_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QTest::PySideQTouchEventSequence >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtTestTypes[SBK_QTEST_PYSIDEQTOUCHEVENTSEQUENCE_IDX]); }
+QT_WARNING_POP
 
 } // namespace Shiboken
 
